<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=bg
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-bg',
	'0_langue' => 'български [bg]',
	'0_liste' => 'spip-bg@rezo.net',
	'0_mainteneur' => 'Christina Haralanova, chris@fsa-bg.org',

	// A
	'access_interface_graphique' => 'Обратно към пълния графичен интерфейс',
	'access_mode_texte' => 'Показване на опростения текстов интерфейс',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Промяна на статията',
	'admin_modifier_auteur' => 'Промяна на автора',
	'admin_modifier_breve' => 'Промяна на новината',
	'admin_modifier_mot' => 'Промяна на ключовата дума',
	'admin_modifier_rubrique' => 'Промяна на рубриката',
	'admin_recalculer' => 'Презареждане на страницата',
	'alerte_maj_impossible' => '<b>Внимание!</b> Базата данни SQL не бе обновена във версия @version@, вероятно поради проблем с правата за достъп.',
	'analyse_xml' => 'Анализиране на XML',
	'antispam_champ_vide' => 'Оставете полето празно:',
	'articles_recents' => 'Най-новите публикувани статии',
	'avis_archive_incorrect' => 'Файлът, който архивирате не е разрешен в СПИП',
	'avis_archive_invalide' => 'Невалиден файл за архивиране',
	'avis_attention' => 'ВНИМАНИЕ!',
	'avis_champ_incorrect_type_objet' => 'Името на полето @name@ е погрешно за обозначаване обект от типа @type@',
	'avis_colonne_inexistante' => 'Колоната @col@ не съществува',
	'avis_erreur' => 'Грешка: прочети по-долу;',
	'avis_erreur_connexion' => 'Грешка при свързването',
	'avis_erreur_cookie' => 'cookie - грешка',
	'avis_erreur_fonction_contexte' => 'Грешка в програмата. Тази команда не трябва да се извиква в този контекст.',
	'avis_erreur_mysql' => 'Грешка в базата данни SQL',
	'avis_erreur_sauvegarde' => 'Грешка при съхраняване (@type@ @id_objet@)!',

	// B
	'barre_a_accent_grave' => 'Впишете главно А с тежко ударение',
	'barre_aide' => 'Използвайте Типографските кратки команди, за да  усъвършенствате външния вид',
	'barre_e_accent_aigu' => 'Впишете главно Е с остро ударение',
	'barre_eo' => 'Впишете дифтонг "ое"',
	'barre_eo_maj' => 'Впишете дифтонг "ОЕ" с главни букви',
	'barre_euro' => 'Добавяне на символа €',
	'barre_gras' => 'Вмъкване на {{удебелен шрифт}}',
	'barre_guillemets' => 'Поставяне в "кавички"',
	'barre_guillemets_simples' => 'Поставяне в ‘единични кавички’',
	'barre_intertitre' => 'Включване режим на {{{подзаглавие}}}',
	'barre_italic' => 'Поставяне в {наклонени букви (italics)}',
	'barre_lien' => 'Превръщане в [препратка->http://...]',
	'barre_lien_input' => 'Моля, впишете препратката в хипертекст (може да напишете Интернет адреса във формата http://www.mysite.com или просто номера на статията от този сайт).',
	'barre_note' => 'Включване режим на [[забележка под линия (footnote)]]',
	'barre_quote' => '<quote>Цитат на съобщение</quote>',
	'bouton_changer' => 'Изпращане',
	'bouton_chercher' => 'Търсене',
	'bouton_choisir' => 'Избор',
	'bouton_download' => 'Télécharger', # MODIF
	'bouton_enregistrer' => 'Записване',
	'bouton_radio_desactiver_messagerie_interne' => 'Без система за вътрешни съобщения',
	'bouton_radio_envoi_annonces' => 'Изпращане на редакторски съобщения',
	'bouton_radio_non_envoi_annonces' => 'Без изпращане на съобщения',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Без изпращане на списък с новини',
	'bouton_recharger_page' => 'Презареждане на страницата',
	'bouton_telecharger' => 'Публикуване',
	'bouton_upload' => 'Публикуване', # MODIF
	'bouton_valider' => 'Изпращане',

	// C
	'cal_apresmidi' => 'следобяд',
	'cal_jour_entier' => 'цял ден',
	'cal_matin' => 'сутрин',
	'cal_par_jour' => 'дневен календар',
	'cal_par_mois' => 'месечен календар',
	'cal_par_semaine' => 'седмичен календар',
	'confirm_changer_statut' => 'Изисква се потвърждение: Задали сте промяна на статуса на статията. Желаете ли до продължите?',
	'correcte' => 'правилно',

	// D
	'date_aujourdhui' => 'днес',
	'date_avant_jc' => 'пр.н.е.',
	'date_dans' => 'в @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'утре',
	'date_fmt_heures_minutes' => '@h@ч.@m@мин.',
	'date_fmt_jour_heure' => '@jour@ в @heure@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour_date' => 'На @nomjour@ @date@',
	'date_heures' => 'часа',
	'date_hier' => 'вчера',
	'date_il_y_a' => 'преди @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10ти',
	'date_jnum11' => '11ти',
	'date_jnum12' => '12ти',
	'date_jnum13' => '13ти',
	'date_jnum14' => '14ти',
	'date_jnum15' => '15ти',
	'date_jnum16' => '16ти',
	'date_jnum17' => '17ти',
	'date_jnum18' => '18ти',
	'date_jnum19' => '19ти',
	'date_jnum2' => '2ри',
	'date_jnum20' => '20ти',
	'date_jnum21' => '21ви',
	'date_jnum22' => '22ри',
	'date_jnum23' => '23ти',
	'date_jnum24' => '24ти',
	'date_jnum25' => '25ти',
	'date_jnum26' => '26ти',
	'date_jnum27' => '27ми',
	'date_jnum28' => '28ми',
	'date_jnum29' => '29ти',
	'date_jnum3' => '3ти',
	'date_jnum30' => '30ти',
	'date_jnum31' => '31ви',
	'date_jnum4' => '4ти',
	'date_jnum5' => '5ти',
	'date_jnum6' => '6ти',
	'date_jnum7' => '7ми',
	'date_jnum8' => '8ми',
	'date_jnum9' => '9ти',
	'date_jour_1' => 'неделя',
	'date_jour_2' => 'понеделник',
	'date_jour_3' => 'вторник',
	'date_jour_4' => 'сряда',
	'date_jour_5' => 'четвъртък',
	'date_jour_6' => 'петък',
	'date_jour_7' => 'събота',
	'date_jours' => 'дни',
	'date_minutes' => 'минути',
	'date_mois' => 'месеца',
	'date_mois_1' => 'януари',
	'date_mois_10' => 'октомври',
	'date_mois_11' => 'ноември',
	'date_mois_12' => 'декември',
	'date_mois_2' => 'февруари',
	'date_mois_3' => 'март',
	'date_mois_4' => 'април',
	'date_mois_5' => 'май',
	'date_mois_6' => 'юни',
	'date_mois_7' => 'юли',
	'date_mois_8' => 'август',
	'date_mois_9' => 'септември',
	'date_saison_1' => 'зима',
	'date_saison_2' => 'пролет',
	'date_saison_3' => 'лято',
	'date_saison_4' => 'есен',
	'date_semaines' => 'седмици',
	'dirs_commencer' => ' за започване на инсталацията',
	'dirs_preliminaire' => 'Предварително: <b>Поправете правата за достъп</b>',
	'dirs_probleme_droits' => 'Проблем с правата на достъп',
	'dirs_repertoires_absents' => '<b>Следните директории не бяха намерени: <ul>@bad_dirs@.</ul> </b>
  <p>Вероятната причина за това е лошото боравене с главните и нормални букви.
  Моля, уверете се, че не е включен режимът за главни букви и че имената на директориите са идентични с тези, показани
  по-горе; ако не са идентични, преименувайте тези директории като използвате FTP клиента, за да поправите грешката.
  <p>След като направите това, можете ', # MODIF
	'dirs_repertoires_suivants' => '<b>Следните директории нямат права за писане: <ul>@bad_dirs@.</ul> </b>

  <p>За да промените правата им, използвайте FTP клиента си, за да зададете права за достъп

  на всяка една от директориите. Процедурата е описана подробно в потребителския наръчник.
  <p>След като приключите с тази операция можете да ', # MODIF

	// E
	'envoi_via_le_site' => 'Изпращане през сайта',

	// F
	'fichier_introuvable' => 'Файлът: @fichier@ не бе намерен',
	'form_deja_inscrit' => 'Вече сте регистриран(а).',
	'form_email_non_valide' => 'Неалиден електронен адрес.',
	'form_forum_access_refuse' => 'Преустановен достъп до сайта',
	'form_forum_bonjour' => 'Добър ден, @nom@,',
	'form_forum_email_deja_enregistre' => 'Този електронен адрес е вече регистриран; за по-нататъшен достъп използвайте обичайната си парола. ',
	'form_forum_identifiant_mail' => 'Новото Ви име за достъп бе изпратено по електронна поща.',
	'form_forum_identifiants' => 'Лични идентификатори ',
	'form_forum_indiquer_nom_email' => 'Попълнете име и електронен адрес. Веднага след това ще получите име за достъп по електронна поща.',
	'form_forum_login' => 'вход:',
	'form_forum_message_auto' => '(това е автоматично съобщение)',
	'form_forum_pass' => 'парола:',
	'form_forum_probleme_mail' => 'Проблем с електронната пощя: грешка при изпращане на идентификатора.',
	'form_forum_voici1' => 'Това са Вашите идентификатори за участие във форумите на сайта
@nom_site_spip@ (@adresse_site@):',
	'form_forum_voici2' => 'Това са Вашите идентификатори за изпращане на статии
на сайта @nom_site_spip@ (@adresse_login@):',
	'form_indiquer_email' => 'Попълнете електронния си адрес.',
	'form_indiquer_nom' => 'Попълнете името си.',
	'form_indiquer_nom_site' => 'Попълнете името на Вашия сайт.',
	'form_pet_deja_enregistre' => 'Сайтът е вече регистриран',
	'form_pet_signature_pasprise' => 'Грешен запис',
	'form_prop_confirmer_envoi' => 'Потвърждение на изпращането',
	'form_prop_description' => 'Описание/коментар',
	'form_prop_enregistre' => 'Вашето предложение е записано. То ще се появи на страниците на сайта след одобрение от администратор. ',
	'form_prop_envoyer' => 'Изпращане на съобщение',
	'form_prop_indiquer_email' => 'Попълнете валиден електронен адрес (e-mail)',
	'form_prop_indiquer_nom_site' => 'Попълнете името на сайта.',
	'form_prop_indiquer_sujet' => 'Попълнете поле Относно',
	'form_prop_message_envoye' => 'Съобщението бе изпратено',
	'form_prop_non_enregistre' => 'Предложението не беше запазено.',
	'form_prop_sujet' => 'Относно',
	'form_prop_url_site' => 'URL на сайта', # MODIF
	'forum_non_inscrit' => 'Или не сте регистрирани, или адресът/ паролата са погрешни.',
	'forum_par_auteur' => 'от @auteur@',
	'forum_titre_erreur' => 'Грешка',

	// I
	'ical_texte_rss_articles' => 'Адресът на файла от крайната точка (backend) е следният:',
	'ical_texte_rss_articles2' => 'Също така, можете да вземете файловете от крайната точка за статиите на всяка рубрика от сайта:',
	'ical_texte_rss_breves' => 'По-нататък има файл, който съдържа новините на сайта. Като изберете номер на рубриката, можете да видите новините само от дадената рубрика.',
	'icone_a_suivre' => 'Начало',
	'icone_admin_site' => 'Администриране на сайта',
	'icone_agenda' => 'Дневник',
	'icone_aide_ligne' => 'Помощник',
	'icone_articles' => 'Статии',
	'icone_auteurs' => 'Автори',
	'icone_brouteur' => 'Бърза навигация',
	'icone_configuration_site' => 'Конфигуриране',
	'icone_configurer_site' => 'Конфигуриране на сайта',
	'icone_creer_nouvel_auteur' => 'Нов автор',
	'icone_creer_rubrique' => 'Създаване на рубрика',
	'icone_creer_sous_rubrique' => 'Създаване на подрубрика',
	'icone_deconnecter' => 'Изход',
	'icone_discussions' => 'Дискусии',
	'icone_doc_rubrique' => 'Документи от рубриките',
	'icone_ecrire_article' => 'Писане на нова статия',
	'icone_edition_site' => 'Редактиране на сайта',
	'icone_gestion_langues' => 'Управление на езиците',
	'icone_informations_personnelles' => 'Лични данни',
	'icone_interface_complet' => 'Пълен интерфейс',
	'icone_interface_simple' => 'Опростен интерфейс',
	'icone_maintenance_site' => 'Поддръжка на сайта',
	'icone_messagerie_personnelle' => 'Лични съобщения',
	'icone_repartition_debut' => 'Покажи началната дистрибуция',
	'icone_rubriques' => 'Рубрики',
	'icone_sauver_site' => 'Запазване на сайта',
	'icone_site_entier' => 'Целият сайт',
	'icone_sites_references' => 'Свързани сайтове',
	'icone_statistiques' => 'Статистика на сайта',
	'icone_suivi_activite' => 'Дейности на сайта',
	'icone_suivi_actualite' => 'Развитие на сайта',
	'icone_suivi_pettions' => 'Допълнения на молби',
	'icone_suivi_revisions' => 'Преглед на статии',
	'icone_supprimer_document' => 'Изтриване на документа',
	'icone_supprimer_image' => 'Изтриване на изображението',
	'icone_tous_articles' => 'Всички Ваши статии',
	'icone_tous_auteur' => 'Всички автори',
	'icone_visiter_site' => 'Посещаване на сайта', # MODIF
	'icone_voir_en_ligne' => 'Изглед на сайта',
	'img_indisponible' => 'изображението липсва',
	'impossible' => 'невъзможно',
	'info_a_suivre' => 'НАЧАЛО»',
	'info_acces_interdit' => 'Забранен достъп',
	'info_acces_refuse' => 'Невъзможен достъп',
	'info_action' => 'Действие: @action@',
	'info_administrer_rubriques' => 'Вие можете да управлявате рубриката и нейните подрубрики',
	'info_adresse_non_indiquee' => 'Укажете адрес за проба!',
	'info_aide' => 'ПОМОЩ:',
	'info_ajouter_mot' => 'Добавяне на ключовата дума',
	'info_annonce' => 'СЪОБЩЕНИЕ',
	'info_annonces_generales' => 'Общи съобщения:',
	'info_article_propose' => 'Изпратена статия',
	'info_article_publie' => 'Одобрена статия',
	'info_article_redaction' => 'Статия в процес на обработка',
	'info_article_refuse' => 'Отхвърлена статия',
	'info_article_supprime' => 'Изтрита статия',
	'info_articles' => 'Статии',
	'info_articles_a_valider' => 'Статии, чакащи одобрение за публикуване',
	'info_articles_proposes' => 'Изпратени статии',
	'info_auteurs_nombre' => 'автор(и):',
	'info_authentification_ftp' => 'Удостоверяване автентичността (чрез FTP).',
	'info_breves_2' => 'новини',
	'info_connexion_refusee' => 'Забранено свързване',
	'info_contact_developpeur' => 'Моля, свържете се с някой разработчик.',
	'info_contenance' => 'Сайтът съдържа:',
	'info_contribution' => 'принос от съобщения във форума', # MODIF
	'info_copyright' => '@spip@ е свободен софтуер, разпространяван @lien_gpl@.',
	'info_copyright_doc' => 'За повече информация, посетете сайта <a href="@spipnet@">http://www.spip.net/bg</a>.', # MODIF
	'info_copyright_gpl' => 'под лиценза GPL',
	'info_cours_edition' => 'Сатиите Ви в процес на обработка',
	'info_creer_repertoire' => 'Моля, създайте файл или директория, наречена:',
	'info_creer_repertoire_2' => 'в под-директорията <b>@repertoire@</b>, след това',
	'info_creer_vignette' => 'автоматично създаване на умален образ',
	'info_deplier' => 'Сгъване',
	'info_descriptif_nombre' => 'описание(я):',
	'info_description' => 'Описание:',
	'info_description_2' => 'Описание:',
	'info_dimension' => 'Размер:',
	'info_ecire_message_prive' => 'Писане на лично съобщение',
	'info_email_invalide' => 'Погрешен електронен адрес.',
	'info_en_cours_validation' => 'Статии в процес на обработка',
	'info_en_ligne' => 'Текущо са в мрежата:',
	'info_envoyer_message_prive' => 'Изпращане на лично съобщение на автора',
	'info_erreur_requete' => 'Грешка при задаване на въпроса:',
	'info_erreur_squelette2' => 'Няма наличен шаблон <b>@fichier@</b>...',
	'info_erreur_systeme' => 'Системна грешка (errno @errsys@)',
	'info_erreur_systeme2' => 'Или твърдият диск е пълен, или базата данни е повредена.<br />
<span style="color:red;">опитайте се<a href=\'@script@\'>да поправите базата данни</a>, или се свържете с доставчика си.</span>',
	'info_fini' => 'Готово!',
	'info_format_image' => 'За създаване на винетките, използвайте същия формат, в който е и изображението: @gd_formats@.',
	'info_format_non_defini' => 'неопределен формат',
	'info_grand_ecran' => 'Увеличен екран',
	'info_image_aide' => 'ПОМОЩНИК',
	'info_image_process_titre' => 'Метод за създаване на умалени образи (винетки)',
	'info_impossible_lire_page' => '<<b>Грешка!</b> Страницата <tt><html>@test_proxy@</html></tt> не се чете през проксито <tt>',
	'info_installation_systeme_publication' => 'Инсталация на системата за публикуване ...',
	'info_installer_documents' => 'Можете автоматично да качвате всички документи от следната папка @upload@.',
	'info_installer_ftp' => 'Като администратор можете да качите файлове (чрез FTP) в папката @upload@, за да ги използвате направо от там, когато Ви потрябват по-късно.',
	'info_installer_images' => 'Форматът на изображенията може да е JPEG, GIF и PNG.',
	'info_installer_images_dossier' => 'Качете изображения в папка @upload@, за да можете да ги използвате направо от там, когато Ви потрябват по-късно.',
	'info_interface_complete' => 'Пълен интерфейс',
	'info_interface_simple' => 'Опростен интерфейс',
	'info_joindre_document_article' => 'Можете към статията да прилагате документи от вида:',
	'info_joindre_document_rubrique' => 'В тази рубрика можете да добавяте документи от вида',
	'info_joindre_documents_article' => 'Можете към статията да прилагате документи от вида:',
	'info_l_article' => 'статията',
	'info_la_breve' => 'новината',
	'info_la_rubrique' => 'рубриката',
	'info_langue_principale' => 'Език на основния сайт',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ пиксели',
	'info_les_auteurs_1' => 'от @les_auteurs@',
	'info_logo_format_interdit' => 'Форматът на логото може да бъде следният: @formats@.',
	'info_logo_max_poids' => 'Логото трябва да е по-малко от @maxi@ (настоящият файл е @actuel@).',
	'info_mail_fournisseur' => 'Вие@isp.com',
	'info_message_2' => 'СЪОБЩЕНИЕ',
	'info_message_supprime' => 'СЪОБЩЕНИЕТО Е ИЗТРИТО',
	'info_mise_en_ligne' => 'Дата на публикация:',
	'info_modification_parametres_securite' => 'промяна настройките на параметрите за сигурност',
	'info_mois_courant' => 'През месеца:',
	'info_mot_cle_ajoute' => 'Следната ключова дума беше добавена към',
	'info_multi_herit' => 'Език по подразбиране',
	'info_multi_langues_soulignees' => '<u>Подчертаните езици</u> осигуряват превод на всички текстове на интерфейса. Ако изберете тези езици, много от елементите на публичния сайт (дати, форми) ще бъдат автоматично преведени. Колкото до неподчертаните езици, елементите ще се появят на основния език за този сайт.', # MODIF
	'info_multilinguisme' => 'Многоезичен',
	'info_nom_non_utilisateurs_connectes' => 'Името Ви е изключено от списъка на свързаните към Интернет потребители',
	'info_nom_utilisateurs_connectes' => 'Името Ви е добавено в списъка на свързаните към Интернет потребители',
	'info_nombre_en_ligne' => 'Текущо са в мрежата:',
	'info_non_resultat' => 'Няма намерени резултати за @cherche_mot@',
	'info_non_utilisation_messagerie' => 'Не използвате системата за вътешни съобщения на този сайт.',
	'info_nouveau_message' => 'ИМАТЕ НОВО СЪОБЩЕНИЕ',
	'info_nouveaux_messages' => 'ИМАТЕ @total_messages@ НОВИ СЪОБЩЕНИЯ',
	'info_numero_abbreviation' => 'Не',
	'info_pense_bete' => 'БЕЛЕЖКА',
	'info_petit_ecran' => 'Малък дисплей',
	'info_pixels' => 'пиксели',
	'info_plusieurs_mots_trouves' => 'Бяха намерени няколко ключови думи за @cherche_mot@:',
	'info_portfolio_automatique' => 'Автоматична папка за документи:',
	'info_premier_resultat' => '[@debut_limit@ първи резултати от общо @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ първи резултати от общо @total@]',
	'info_propose_1' => '[@nom_site_spip@] Изпратени: @titre@',
	'info_propose_2' => 'Изпратена статия
-----------------',
	'info_propose_3' => 'Статията @titre@ е изпратена за публикуване.',
	'info_propose_4' => 'Моля, прегледайте и коментирайте',
	'info_propose_5' => 'във форума, който е на адрес:',
	'info_publie_01' => 'Статията @titre@ бе одобрена за публикуване от @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] ПУБЛИКУВА: @titre@',
	'info_publie_2' => 'Публикувана статия
------------------',
	'info_rechercher' => 'Търсене',
	'info_rechercher_02' => 'Търсене:',
	'info_remplacer_vignette' => 'Смяна на винетката по подразбиране с лого по избор:',
	'info_sans_titre_2' => 'без заглавие',
	'info_selectionner_fichier' => 'Избиране на файл от папка @upload@',
	'info_selectionner_fichier_2' => 'Изберете файл:',
	'info_supprimer_vignette' => 'изтриване на винетката',
	'info_symbole_bleu' => 'Символът <b>синьо</b> указва <b>бележка</b>: т.е. съобщение за лично ползване.',
	'info_symbole_jaune' => 'Символът <b>жълто</b> указва  <b>съобщение към всички редактори</b>: то може да се вписва само от администратори и да се вижда от всички редактори.',
	'info_symbole_vert' => 'Символът <b>зелено</b> указва <b>съобщения, обменени с други потребители</b> на сайта.',
	'info_telecharger_nouveau_logo' => 'Качване на ново лого:',
	'info_telecharger_ordinateur' => 'Качете от своя компютър на сайта:',
	'info_tous_resultats_enregistres' => '[всички резултати са записани]',
	'info_tout_afficher' => 'Показване на всички',
	'info_travaux_texte' => 'Този сайт още не е поместен. Елате по-късно. ',
	'info_travaux_titre' => 'Сайтът е в процес на израбоване ',
	'info_trop_resultat' => 'Твърде много намерени резултати за @cherche_mot@; моля, прецизирайте търсенето си.',
	'info_utilisation_messagerie_interne' => 'Вие използвате системата за вътрешни съобщения на сайта.',
	'info_valider_lien' => 'одобряване на препратката',
	'info_verifier_image' => ', уверете се, че вашите изображения са прехвърлени правилно.',
	'info_vignette_defaut' => 'Винетка по подразбиране',
	'info_vignette_personnalisee' => 'Винетка по избор',
	'info_visite' => 'посещение:',
	'info_vos_rendez_vous' => 'Вашите бъдещи срещи',
	'infos_vos_pense_bete' => 'Лични бележки', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Показване само на икони',
	'lien_afficher_texte_icones' => 'Показване икони и текст',
	'lien_afficher_texte_seul' => 'Показване само на текст',
	'lien_liberer' => 'освобождаване',
	'lien_liberer_tous' => 'освобождаване на статиите', # MODIF
	'lien_nouvea_pense_bete' => 'НОВА БЕЛЕЖКА',
	'lien_nouveau_message' => 'НОВО СЪОБЩЕНИЕ',
	'lien_nouvelle_annonce' => 'НОВО СЪОБЩЕНИЕ',
	'lien_petitions' => 'МОЛБА',
	'lien_popularite' => 'популярност: @popularite@%',
	'lien_racine_site' => 'СХЕМА НА САЙТА',
	'lien_reessayer' => 'опитайте отново',
	'lien_repondre_message' => 'Отговор на съобщението',
	'lien_supprimer' => 'изтриване',
	'lien_tout_afficher' => 'Показване на всички',
	'lien_visite_site' => 'посещаване на сайта',
	'lien_visites' => '@visites@ посещения',
	'lien_voir_auteur' => 'Проверка на автора',
	'login_acces_prive' => 'достъп до личната зона',
	'login_autre_identifiant' => 'свързване с друго потребителско име',
	'login_cookie_accepte' => 'Моля, настройте Интернет навигатора да приеме cookie (поне за този сайт).',
	'login_cookie_oblige' => 'За по-сигурно идентифициране, приемете cookie.',
	'login_deconnexion_ok' => 'Излязохте успешно.',
	'login_erreur_pass' => 'Погрешна парола.',
	'login_espace_prive' => 'лична зона',
	'login_identifiant_inconnu' => 'Непознат потребител @login@.',
	'login_login' => 'Вход:',
	'login_login2' => 'Вход (потребителско име за свързване със сайта):', # MODIF
	'login_login_pass_incorrect' => '(Погрешно потребителско име или парола).',
	'login_motpasseoublie' => 'забравена парола?',
	'login_non_securise' => 'Внимание! Тази форма не е защитена.

   Ако не желаете паролата Ви да бъде

   разкрита в мрежата, активирайте Javascript 

   на навигатора и ',
	'login_nouvelle_tentative' => 'Нов опит',
	'login_par_ici' => 'Успешна регистрация... насам...',
	'login_pass2' => 'Парола:',
	'login_preferez_refuser' => '<b>Ако предпочитате да откажете cookies</b>, на Ваше разположение e предоставена друга възможност за свързване (по-малко сигурна):',
	'login_recharger' => 'обновете тази страница',
	'login_rester_identifie' => 'Идентифициран за по-дълго време (няколко дни)',
	'login_retour_public' => 'Обратно към публичния сайт',
	'login_retour_site' => 'Обратно към публичния сайт',
	'login_retoursitepublic' => 'обратно към публичния сайт',
	'login_sinscrire' => 'регистрирация',
	'login_test_navigateur' => 'тест на навигатор/повторно свързване',
	'login_verifiez_navigateur' => '(Въпреки това, убедете се, че навигаторът не е запаметил Вашата парола...)',

	// M
	'module_fichiers_langues' => 'Езикови файлове',

	// N
	'navigateur_pas_redirige' => 'Ако интернет-навигаторът не Ви пренасочи, натиснете тук, за да продължите.',

	// O
	'onglet_affacer_base' => 'Изтриване на базата данни',
	'onglet_auteur' => 'Авторът',
	'onglet_contenu_site' => 'Съдържание на сайта',
	'onglet_evolution_visite_mod' => 'Развитие',
	'onglet_fonctions_avances' => 'Подробни функции',
	'onglet_informations_personnelles' => 'Лични данни',
	'onglet_interactivite' => 'Интерактивност',
	'onglet_messagerie' => 'Система за съобщения',
	'onglet_repartition_rubrique' => 'Разпределение по рубрики',
	'onglet_save_restaur_base' => 'Архивиране/възстановяване на базата данни',
	'onglet_vider_cache' => 'Изпразване на кеш-паметта',

	// P
	'pass_choix_pass' => 'Изберете нова парола:',
	'pass_erreur' => 'Грешка',
	'pass_erreur_acces_refuse' => '<b>Грешка:</b> нямате повече достъп до този сайт.',
	'pass_erreur_code_inconnu' => '<b>Грешка:</b> този код не съвпада с никой посетител, който има разрешение за достъп до сайта.',
	'pass_erreur_non_enregistre' => '<b>Грешка:</b> адресът <tt>@email_oubli@</tt> не е регистриран в сайта.',
	'pass_erreur_non_valide' => '<b>Грешка:</b> електронният адрес <tt>@email_oubli@</tt> е погрешен!',
	'pass_erreur_probleme_technique' => '<b>Грешка:</b> това писмо не може да бъде изпратено поради технически проблем.',
	'pass_espace_prive_bla' => 'Личната зона на сайта е отворена само за
регистирани посетители. След като се регистрирате,
можете да преглеждате статиите, които са в
в процес на обработка, да изпращате статии и да участвате във всички форуми.',
	'pass_forum_bla' => 'Пожелали сте да участвате във форум, който
е запазен за регистрирани посетители.',
	'pass_indiquez_cidessous' => 'Попълнете електронният адрес, с който
сте регистрирани.
Ще получите писмо с инструкции за това, как
да подновите достъпа си.',
	'pass_mail_passcookie' => '(това е автоматично съобщение)

За да получите достъп до сайта
@nom_site_spip@ (@adresse_site@)

Моля, посетете следния адрес:
    @sendcookie@

След това можете да смените паролата
и да се свържете към сайта отново.
',
	'pass_mot_oublie' => 'Забравена парола',
	'pass_nouveau_enregistre' => 'Новата Ви парола бе запазена.',
	'pass_nouveau_pass' => 'Нова парола',
	'pass_ok' => 'Изпращане',
	'pass_oubli_mot' => 'Забравена парола',
	'pass_quitter_fenetre' => 'Затваряне на прозореца',
	'pass_rappel_login' => 'Напомняне: Вашето потребителско име (идентификатор) е @login@.',
	'pass_recevoir_mail' => 'Ще получите писмо с инструкции за това, как
да подновите достъпа си до сайта.',
	'pass_retour_public' => 'Обратно в публичния сайт',
	'pass_rien_a_faire_ici' => 'Нямате работа тук.',
	'pass_vousinscrire' => 'Регистриране на сайта',
	'precedent' => 'предишен',
	'previsualisation' => 'Предварителен преглед',
	'previsualiser' => 'Показване на предварителния преглед',

	// S
	'squelette' => 'шаблон',
	'squelette_inclus_ligne' => 'включен шаблон, ред',
	'squelette_ligne' => 'шаблон, ред',
	'stats_visites_et_popularite' => '@visites@ посещения; популярност: @popularite@',
	'suivant' => 'следващ',

	// T
	'taille_ko' => '@taille@ KB',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => '@taille@ байта',
	'texte_actualite_site_1' => 'След като се запознаете с интерфейса, изберете «',
	'texte_actualite_site_2' => 'пълен интерфейс',
	'texte_actualite_site_3' => ' » да направите повече свойства активни.',
	'texte_creation_automatique_vignette' => 'Позволено е автоматичното създаване на предварителни умалени образи в сайта. Ако качите изображения през тази форма, във формат(и) @gd_formats@, те ще бъдат удвоени с умалени образи, чийто максимален размер е @taille_preview@ пиксели. ',
	'texte_documents_associes' => 'Следните документи са свързани със статията,,
    но те не са пряко включени в
    нея. Според оформлението в публичния сайт, те биха
    могли да се запишат като приложени документи.',
	'texte_erreur_mise_niveau_base' => 'Грешка в базата данни по време на актуализация.
      Изображението <b>@fichier@</b> е несъвместимо със статията (article @id_article@).<p>
      Отбележете внимателно тази връзка; повторете процедурата по актуализация
      и се уверете, че изображението все още е приложено
      към статиите.',
	'texte_inc_auth_1' => 'Вие се идентифицирате с потребителско име
  <b>@auth_login@</b>, но то (вече) не съществува в базата данни. 
  Опитайте да', # MODIF
	'texte_inc_auth_2' => 'повторно свързване',
	'texte_inc_auth_3' => 'след като излезете
  презаредете навигатора си, ако се налага.',
	'texte_inc_config' => 'Промените, които са направени по-долу оказват изключително голямо влияние на работата на сайта. Съветваме Ви да не ги пипате, освен ако не сте добре запознати с работата на системата СПИП. <br /><br /><b>Силно  Ви препоръчваме да оставите главния уеб администратор да работи с тази страница.</b>',
	'texte_inc_meta_1' => 'Системата намери грешка при опит за запис във файла <code>@fichier@</code>. Като администратор на сайта, моля да направите ',
	'texte_inc_meta_2' => 'проверка на позволенията за запис',
	'texte_inc_meta_3' => 'на директорията <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'в процес на обработка',
	'texte_statut_poubelle' => 'за изтриване',
	'texte_statut_propose_evaluation' => 'чакаща оценка',
	'texte_statut_publie' => 'публикувана на сайта',
	'texte_statut_refuse' => 'отхвърлена',
	'titre_ajouter_mot_cle' => 'ДОБАВЯНЕ НА КЛЮЧОВА ДУМА:',
	'titre_cadre_raccourcis' => 'КОМАНДИ ЗА УСКОРЕН ДОСТЪП:',
	'titre_changer_couleur_interface' => 'Смяна цвета на интерфейса',
	'titre_image_admin_article' => 'Администриране на статията',
	'titre_image_administrateur' => 'Администратор',
	'titre_image_aide' => 'Помощник за тази част',
	'titre_image_auteur_supprime' => 'Авторът е изтрит',
	'titre_image_redacteur' => 'Редактор без достъп',
	'titre_image_redacteur_02' => 'Редактор',
	'titre_image_visiteur' => 'Посетител',
	'titre_joindre_document' => 'ПРИЛАГАНЕ НА ДОКУМЕНТ',
	'titre_mots_cles' => 'КЛЮЧОВИ ДУМИ',
	'titre_probleme_technique' => 'Предупреждение: технически проблем (сървъра SQL) затруднява достъпа до тази част от сайта.<p>Благодарим за разбирането.',
	'titre_publier_document' => 'ПУБЛИКУВАНЕ НА ДОКУМЕНТ В ТАЗИ РУБРИКА',
	'titre_statistiques' => 'Страница на статистиката',
	'titre_titre_document' => 'Наименование на документа:',
	'trad_reference' => '(свързване на статия)', # MODIF

	// Z
	'zbug_balise_b_aval' => ': Таг "B" се явява прекалено къно в цикъла',
	'zbug_boucle' => 'цикъл',
	'zbug_boucle_recursive_undef' => 'неопределен рекурсивен цикъл', # MODIF
	'zbug_champ_hors_boucle' => 'Полето @champ@ е извън цикъла',
	'zbug_champ_hors_motif' => 'Полето @champ@ извън цикъла е с елемент @motif@', # MODIF
	'zbug_code' => 'код',
	'zbug_critere_inconnu' => 'непознат критерий @critere@', # MODIF
	'zbug_distant_interdit' => 'забрана за външни данни', # MODIF
	'zbug_erreur_boucle_double' => 'BOUCLE@id@: двойна дефиниция', # MODIF
	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: липсва затварящ "таг" (<>)', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Неправилен синтакс на цикъл (BOUCLE)', # MODIF
	'zbug_erreur_execution_page' => 'грешка при задаване на страницата', # MODIF
	'zbug_erreur_filtre' => 'Грешка: неопределен филтър: <b>@filtre@</b>', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} се отнася само за циклите (FORUMS) и (RUBRIQUES)', # MODIF
	'zbug_erreur_squelette' => 'Грешка(и) в шаблона',
	'zbug_info_erreur_squelette' => 'ُГрешка на сайта',
	'zbug_inversion_ordre_inexistant' => 'обръщане в несъществуващ ред', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Погрешни параметри за включване', # MODIF
	'zbug_resultat' => 'резултат',
	'zbug_serveur_indefini' => 'неопределен сървър SQL', # MODIF
	'zbug_table_inconnue' => 'Непозната таблица от типа SQL: "@table@"'
);

?>
